@@ -24,9 +24,6 @@
 #define PTY_H
 
 // Qt
-#include <QtCore/QStringList>
-#include <QtCore/QVector>
-#include <QtCore/QList>
 #include <QtCore/QSize>
 
 // KDE
@@ -35,9 +32,10 @@
 // Konsole
 #include "konsole_export.h"
 
+class QStringList;
+
 namespace Konsole
 {
-
 /**
  * The Pty class is used to start the terminal process,
  * send data to it, receive data from it and manipulate
@@ -51,15 +49,14 @@ namespace Konsole
  * To start the terminal process, call the start() method
  * with the program name and appropriate arguments.
  */
-class KONSOLEPRIVATE_EXPORT Pty: public KPtyProcess
+class Pty: public KPtyProcess
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
-
     /**
      * Constructs a new Pty.
-     * 
+     *
      * Connect to the sendData() slot and receivedData() signal to prepare
      * for sending and receiving data from the terminal process.
      *
@@ -87,22 +84,13 @@ public:
      * @param environment A list of key=value pairs which will be added
      * to the environment for the new process.  At the very least this
      * should include an assignment for the TERM environment variable.
-     * @param winid Specifies the value of the WINDOWID environment variable
-     * in the process's environment.
      * @param addToUtmp Specifies whether a utmp entry should be created for
      * the pty used.  See K3Process::setUsePty()
-     * @param dbusService Specifies the value of the KONSOLE_DBUS_SERVICE
-     * environment variable in the process's environment.
-     * @param dbusSession Specifies the value of the KONSOLE_DBUS_SESSION
-     * environment variable in the process's environment.
      */
-    int start( const QString& program, 
-               const QStringList& arguments, 
-               const QStringList& environment, 
-               ulong winid, 
-               bool addToUtmp,
-               const QString& dbusService,
-               const QString& dbusSession
+    int start(const QString& program,
+              const QStringList& arguments,
+              const QStringList& environment,
+              bool addToUtmp
              );
 
     /** Control whether the pty device is writeable by group members. */
@@ -151,24 +139,17 @@ public:
      */
     int foregroundProcessGroup() const;
 
-public slots:
+    /**
+     * Close the underlying pty master/slave pair.
+     */
+    void closePty();
 
+public slots:
     /**
      * Put the pty into UTF-8 mode on systems which support it.
      */
     void setUtf8Mode(bool on);
 
-    /**
-     * Suspend or resume processing of data from the standard
-     * output of the terminal process.
-     *
-     * See K3Process::suspend() and K3Process::resume()
-     *
-     * @param lock If true, processing of output is suspended,
-     * otherwise processing is resumed.
-     */
-    void lockPty(bool lock);
-
     /**
      * Sends data to the process currently controlling the
      * teletype ( whose id is returned by foregroundProcessGroup() )
@@ -179,7 +160,6 @@ public slots:
     void sendData(const char* buffer, int length);
 
 signals:
-
     /**
      * Emitted when a new block of data is received from
      * the teletype.
@@ -194,23 +174,21 @@ protected:
 
 private slots:
     // called when data is received from the terminal process
-    void dataReceived(); 
+    void dataReceived();
 
 private:
-
     void init();
 
     // takes a list of key=value pairs and adds them
     // to the environment for the process
     void addEnvironmentVariables(const QStringList& environment);
 
-    int  _windowColumns; 
+    int  _windowColumns;
     int  _windowLines;
     char _eraseChar;
     bool _xonXoff;
     bool _utf8;
 };
-
 }
 
 #endif // PTY_H
