@@ -28,7 +28,6 @@
 #include <QtCore/QSet>
 #include <QtCore/QVector>
 #include <QtCore/QBitArray>
-#include <QtCore/QTextStream>
 #include <QtCore/QVarLengthArray>
 
 // Konsole
@@ -44,7 +43,6 @@
 
 namespace Konsole
 {
-
 class TerminalCharacterDecoder;
 class TerminalDisplay;
 class HistoryType;
@@ -370,7 +368,7 @@ public:
      * @param startLine Index of first line to copy
      * @param endLine Index of last line to copy
      */
-    void getImage( Character* dest , int size , int startLine , int endLine ) const;
+    void getImage(Character* dest , int size , int startLine , int endLine) const;
 
     /**
      * Returns the additional attributes associated with lines in the image.
@@ -378,15 +376,16 @@ public:
      * line is wrapped,
      * other attributes control the size of characters in the line.
      */
-    QVector<LineProperty> getLineProperties( int startLine , int endLine ) const;
-
+    QVector<LineProperty> getLineProperties(int startLine , int endLine) const;
 
     /** Return the number of lines. */
-    int getLines() const   
-    { return lines; }
+    int getLines() const {
+        return _lines;
+    }
     /** Return the number of columns. */
-    int getColumns() const 
-    { return columns; }
+    int getColumns() const {
+        return _columns;
+    }
     /** Return the number of lines in the history buffer. */
     int getHistLines() const;
     /**
@@ -439,7 +438,7 @@ public:
       *  Returns true if the character at (@p column, @p line) is part of the
       *  current selection.
       */
-    bool isSelected(const int column,const int line) const;
+    bool isSelected(const int column, const int line) const;
 
     /**
      * Convenience method.  Returns the currently selected text.
@@ -448,6 +447,13 @@ public:
      */
     QString selectedText(bool preserveLineBreaks) const;
 
+    /**
+     * Convenience method.  Returns the text from @p startIndex to @p endIndex.
+     * @param preserveLineBreaks Specifies whether new line characters should
+     * be inserted into the returned text at the end of each terminal line.
+     */
+    QString text(int startIndex, int endIndex, bool preserveLineBreaks) const;
+
     /**
      * Copies part of the output to a stream.
      *
@@ -547,26 +553,20 @@ public:
       */
     static void fillWithDefaultChar(Character* dest, int count);
 
-    void setCurrentTerminalDisplay(TerminalDisplay* display)
-    {
-	   _currentTerminalDisplay = display;
+    void setCurrentTerminalDisplay(TerminalDisplay* display) {
+        _currentTerminalDisplay = display;
     }
 
-    TerminalDisplay* currentTerminalDisplay()
-    {
+    TerminalDisplay* currentTerminalDisplay() {
         return _currentTerminalDisplay;
     }
 
-    QSet<ushort> usedExtendedChars() const
-    {
+    QSet<ushort> usedExtendedChars() const {
         QSet<ushort> result;
-        for (int i = 0; i < lines; ++i)
-        {
-            const ImageLine& il = screenLines[i];
-            for (int j = 0; j < columns; ++j)
-            {
-                if (il[j].rendition & RE_EXTENDED_CHAR)
-                {
+        for (int i = 0; i < _lines; ++i) {
+            const ImageLine& il = _screenLines[i];
+            for (int j = 0; j < _columns; ++j) {
+                if (il[j].rendition & RE_EXTENDED_CHAR) {
                     result << il[j].character;
                 }
             }
@@ -574,10 +574,9 @@ public:
         return result;
     }
 
-    static const Character defaultChar;
+    static const Character DefaultChar;
 
 private:
-
     //copies a line of text from the screen or history into a stream using a
     //specified character decoder.  Returns the number of lines actually copied,
     //which may be less than 'count' if (start+count) is more than the number of characters on
@@ -589,9 +588,9 @@ private:
     //count - the number of characters on the line to copy
     //decoder - a decoder which converts terminal characters (an Character array) into text
     //appendNewLine - if true a new line character (\n) is appended to the end of the line
-    int  copyLineToStream(int line, 
-                          int start, 
-                          int count, 
+    int  copyLineToStream(int line,
+                          int start,
+                          int count,
                           TerminalCharacterDecoder* decoder,
                           bool appendNewLine,
                           bool preserveLineBreaks) const;
@@ -625,7 +624,7 @@ private:
     bool isSelectionValid() const;
     // copies text from 'startIndex' to 'endIndex' to a stream
     // startIndex and endIndex are positions generated using the loc(x,y) macro
-    void writeToStream(TerminalCharacterDecoder* decoder, int startIndex, 
+    void writeToStream(TerminalCharacterDecoder* decoder, int startIndex,
                        int endIndex, bool preserveLineBreaks = true) const;
     // copies 'count' lines from the screen buffer into 'dest',
     // starting from 'startLine', where 0 is the first line in the screen buffer
@@ -634,61 +633,60 @@ private:
     // starting from 'startLine', where 0 is the first line in the history
     void copyFromHistory(Character* dest, int startLine, int count) const;
 
-
     // screen image ----------------
-    int lines;
-    int columns;
+    int _lines;
+    int _columns;
 
     typedef QVector<Character> ImageLine;      // [0..columns]
-    ImageLine*          screenLines;    // [lines]
+    ImageLine*          _screenLines;    // [lines]
 
     int _scrolledLines;
     QRect _lastScrolledRegion;
 
     int _droppedLines;
 
-    QVarLengthArray<LineProperty,64> lineProperties;    
+    QVarLengthArray<LineProperty, 64> _lineProperties;
 
     // history buffer ---------------
-    HistoryScroll* history;
+    HistoryScroll* _history;
 
     // cursor location
-    int cuX;
-    int cuY;
+    int _cuX;
+    int _cuY;
 
     // cursor color and rendition info
-    CharacterColor currentForeground;
-    CharacterColor currentBackground;
-    quint8 currentRendition; 
+    CharacterColor _currentForeground;
+    CharacterColor _currentBackground;
+    quint8 _currentRendition;
 
     // margins ----------------
     int _topMargin;
     int _bottomMargin;
 
     // states ----------------
-    int currentModes[MODES_SCREEN];
-    int savedModes[MODES_SCREEN];
+    int _currentModes[MODES_SCREEN];
+    int _savedModes[MODES_SCREEN];
 
     // ----------------------------
 
-    QBitArray tabStops;
+    QBitArray _tabStops;
 
     // selection -------------------
-    int selBegin; // The first location selected.
-    int selTopLeft;    // TopLeft Location.
-    int selBottomRight;    // Bottom Right Location.
-    bool blockSelectionMode;  // Column selection mode
+    int _selBegin; // The first location selected.
+    int _selTopLeft;    // TopLeft Location.
+    int _selBottomRight;    // Bottom Right Location.
+    bool _blockSelectionMode;  // Column selection mode
 
     // effective colors and rendition ------------
-    CharacterColor effectiveForeground; // These are derived from
-    CharacterColor effectiveBackground; // the cu_* variables above
-    quint8 effectiveRendition;          // to speed up operation
+    CharacterColor _effectiveForeground; // These are derived from
+    CharacterColor _effectiveBackground; // the cu_* variables above
+    quint8 _effectiveRendition;          // to speed up operation
 
-    class SavedState  
+    class SavedState
     {
     public:
         SavedState()
-        : cursorColumn(0),cursorLine(0),rendition(0) {}
+            : cursorColumn(0), cursorLine(0), rendition(0) {}
 
         int cursorColumn;
         int cursorLine;
@@ -696,13 +694,11 @@ private:
         CharacterColor foreground;
         CharacterColor background;
     };
-    SavedState savedState;
+    SavedState _savedState;
 
     // last position where we added a character
-    int lastPos;
-
+    int _lastPos;
 };
-
 }
 
 #endif // SCREEN_H
