@@ -23,9 +23,11 @@
 // Qt
 #include <QtCore/QStringList>
 
+// Konsole
+#include "konsole_export.h"
+
 namespace Konsole
 {
-
 /**
  * A class to parse and extract information about shell commands.
  *
@@ -47,19 +49,19 @@ namespace Konsole
  *      </li>
  * </ul>
  */
-class ShellCommand
+class KONSOLEPRIVATE_EXPORT ShellCommand
 {
 public:
     /**
      * Constructs a ShellCommand from a command line.
      *
-     * @param fullCommand The command line to parse.
+     * @param aCommand The command line to parse.
      */
-    ShellCommand(const QString& fullCommand);
+    explicit ShellCommand(const QString& aCommand);
     /**
-     * Constructs a ShellCommand with the specified @p command and @p arguments.
+     * Constructs a ShellCommand with the specified @p aCommand and @p aArguments.
      */
-    ShellCommand(const QString& command , const QStringList& arguments);
+    ShellCommand(const QString& aCommand, const QStringList& aArguments);
 
     /** Returns the command. */
     QString command() const;
@@ -85,7 +87,6 @@ public:
 private:
     QStringList _arguments;
 };
-
 }
 
 #endif // SHELLCOMMAND_H
